==> ember-0.4.0.tar.bz2: ember-0.4.0/src/components/ogre/SceneManagers/EmberPagingSceneManager/include/OgrePagingLandScapeTexture_Splatting5.h <==
/***************************************************************************
OgrePagingLandScapeTexture_Splatting5.h  -  description
	-------------------
	begin                : Mon Apr 16 2004
	copyright            : (C) 2002-2005 by Jose A Milan & Tuan Kuranes
	email                : spoke@supercable.es & tuan.kuranes@free.fr
***************************************************************************/

/***************************************************************************
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU Lesser General Public License as        *
*   published by the Free Software Foundation; either version 2 of the    *
*   License, or (at your option) any later version.                       *
*                                                                         *
***************************************************************************/

#ifndef PAGINGLandScapeTEXTURE5_SPLATTING_H
#define PAGINGLandScapeTEXTURE5_SPLATTING_H

#include "OgrePagingLandScapePrerequisites.h"
#include "OgrePagingLandScapeTexture.h"

namespace Ogre
{

    class PagingLandScapeTexture_Splatting5 : public PagingLandScapeTexture
    {
        public:
	        PagingLandScapeTexture_Splatting5(void);
            virtual String getName(){return String("Splatting5");}
                    
            static void _setPagesize(void);
            static void _clearData(void);
            
	        virtual ~PagingLandScapeTexture_Splatting5(void);

            virtual PagingLandScapeTexture* newTexture();
            virtual bool TextureRenderCapabilitesFullfilled(); 

        protected:
	        virtual void _loadMaterial(void);

    };
}

#endif

==> ember-0.4.1.tar.bz2: ember-0.4.1/src/components/ogre/SceneManagers/EmberPagingSceneManager/include/OgrePagingLandScapeTexture_Splatting5.h <==
/***************************************************************************
OgrePagingLandScapeTexture_Splatting5.h  -  description
	-------------------
	begin                : Mon Apr 16 2004
	copyright            : (C) 2002-2005 by Jose A Milan & Tuan Kuranes
	email                : spoke@supercable.es & tuan.kuranes@free.fr
***************************************************************************/

/***************************************************************************
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU Lesser General Public License as        *
*   published by the Free Software Foundation; either version 2 of the    *
*   License, or (at your option) any later version.                       *
*                                                                         *
***************************************************************************/

#ifndef PAGINGLandScapeTEXTURE5_SPLATTING_H
#define PAGINGLandScapeTEXTURE5_SPLATTING_H

#include "OgrePagingLandScapePrerequisites.h"
#include "OgrePagingLandScapeTexture.h"

namespace Ogre
{

    class PagingLandScapeTexture_Splatting5 : public PagingLandScapeTexture
    {
        public:
	        PagingLandScapeTexture_Splatting5(PagingLandScapeTextureManager *textureMgr);
            virtual String getName(){return String("Splatting5");}
                    
            void _setPagesize(void);
            void _clearData(void);
            
	        virtual ~PagingLandScapeTexture_Splatting5(void);

            virtual PagingLandScapeTexture* newTexture();
            virtual bool TextureRenderCapabilitesFullfilled(); 

        protected:
	        virtual void _loadMaterial(void);

    };
}

#endif
